package net.minecraft.src;

import java.util.ArrayList;
import java.util.Map;
import java.util.Random;

import net.minecraft.server.MinecraftServer;

// SDK
public class mod_SdkUtility extends BaseMod
{
    public static final Block blockGrinder = (new SdkBlockGrinder(120, ModLoader.getUniqueSpriteIndex("/terrain.png"))).setHardness(3.5F).setStepSound(Block.soundStoneFootstep).func_20037_a("blockGrinder");
    
    public static final Item itemGoldCoin = (new Item(2509)).setIconIndex(ModLoader.getUniqueSpriteIndex("/gui/items.png")).func_20105_a("goldCoin");
    public static final Item itemLightometer = (new Item(2510)).setIconIndex(ModLoader.getUniqueSpriteIndex("/gui/items.png")).func_20105_a("lightometer");
    public static final Item itemNightvisionGoggles = (new ItemArmor(2513, -1, 0, 0)).setIconIndex(ModLoader.getUniqueSpriteIndex("/gui/items.png")).func_20105_a("nightvisionGoggles");
    public static final Item itemScubaTank = (new ItemArmor(2521, -1, 0, 1)).setIconIndex(ModLoader.getUniqueSpriteIndex("/gui/items.png")).func_20105_a("scubaTank");
    public static final Item itemParachute = (new SdkItemParachute(2523, 0)).setIconIndex(ModLoader.getUniqueSpriteIndex("/gui/items.png")).func_20105_a("parachute");
	
	public static Random random = new Random();
	
	public mod_SdkUtility()
    {
		ModLoader.RegisterBlock(blockGrinder);

		ModLoader.RegisterEntityID(SdkEntityParachute.class, "Parachute", ModLoader.getUniqueEntityId());
		
		ModLoader.RegisterTileEntity(SdkTileEntityGrinder.class, "Grinder");
    }
	
	@Override
	public String Version()
	{
		return "1.2_02v2";
	}
	
	@Override
	public void Tick(MinecraftServer minecraftServer)
	{
		for(EntityPlayerMP e : new ArrayList<EntityPlayerMP>(minecraftServer.configManager.playerEntities))
		{
			ItemStack itemstack = e.inventory.armorInventory[2];
	        if(itemstack != null && itemstack.itemID == itemScubaTank.swiftedIndex)
	        {
	        	e.air = e.maxAir;
	        }
		}
	}

	@Override
    public void AddRecipes(CraftingManager craftingmanager)
    {
		craftingmanager.func_20153_a(new ItemStack(itemGoldCoin, 4), new Object[] {
            "#", Character.valueOf('#'), Item.ingotGold
        });
		craftingmanager.func_20153_a(new ItemStack(itemLightometer, 1), new Object[] {
        	" # ", "#X#", " # ", Character.valueOf('#'), Item.ingotIron, Character.valueOf('X'), Item.lightStoneDust
        });
		craftingmanager.func_20153_a(new ItemStack(itemNightvisionGoggles, 1), new Object[] {
        	"#X#", Character.valueOf('#'), Item.diamond, Character.valueOf('X'), Item.silk
        });
		craftingmanager.func_20153_a(new ItemStack(itemScubaTank, 1), new Object[] {
        	"###", "# #", "###", Character.valueOf('#'), Item.ingotIron
        });
		craftingmanager.func_20153_a(new ItemStack(itemParachute, 1), new Object[] {
        	"###", "XYX", "YYY", Character.valueOf('#'), Block.cloth, Character.valueOf('X'), Item.silk, Character.valueOf('Y'), Item.leather
        });
		craftingmanager.func_20153_a(new ItemStack(blockGrinder, 1), new Object[] {
        	"###", "#X#", "###", Character.valueOf('#'), Block.cobblestone, Character.valueOf('X'), Item.diamond
        });
    }
	
	@Override
	public void AddEntityTrackers(Map<Class, SdkPair<Integer, Integer>> map)
	{
		map.put(SdkEntityParachute.class, new SdkPair<Integer, Integer>(160, 3));
	}
	
	@Override
	public void AddEntityTrackerEntries(Map<Class, Integer> map)
	{
		map.put(SdkEntityParachute.class, 120);
	}
	
	@Override
	public void HandlePacket(Packet200ModLoader packet200ModLoader, EntityPlayerMP entityPlayerMp)
	{
		switch(packet200ModLoader.packetType)
		{
			case 0:
			{
				handleParachuteKey(entityPlayerMp);
				break;
			}
		}
	}
	
	public static void handleParachuteKey(EntityPlayer entityPlayer)
	{
		ItemStack itemstack = entityPlayer.inventory.armorInventory[2];
		if(itemstack != null && itemstack.itemID == itemParachute.swiftedIndex)
		{
			itemstack.useItemRightClick(ModLoader.getMinecraftServerInstance().worldMngr, entityPlayer);
		}
	}
	
	private void useParachute(ItemStack itemstack, World world, EntityPlayer entityplayer)
	{
		if(!SdkEntityParachute.onGroundOrInWater(world, entityplayer))
    	{
	        itemstack.damageItem(1);
            if(itemstack.stackSize == 0)
            {
            	boolean removed = false;
            	for(int i = 0; i < entityplayer.inventory.armorInventory.length; i++)
            	{
            		if(entityplayer.inventory.armorInventory[i] == itemstack)
            		{
            			entityplayer.inventory.armorInventory[i] = null;
            			removed = true;
            			break;
            		}
            	}
            	
            	if(!removed)
            	{
	            	for(int i = 0; i < entityplayer.inventory.mainInventory.length; i++)
	            	{
	            		if(entityplayer.inventory.mainInventory[i] == itemstack)
	            		{
	            			entityplayer.inventory.mainInventory[i] = null;
	            			removed = true;
	            			break;
	            		}
	            	}
            	}
            }
	        
	        world.playSoundAtEntity(entityplayer, "parachute", 0.5F, 1.0F / (random.nextFloat() * 0.1F + 0.95F));
	        
	        if(!world.multiplayerWorld)
	        {
	        	world.entityJoinedWorld(new SdkEntityParachute(world, entityplayer));
	        }
    	}
	}
}
